==> ppgs-0.0.2.tar.gz: ppgs-0.0.2/ppgs/plot/__main__.py <==
import yapecs
from pathlib import Path

import ppgs


###############################################################################
# PPG inference command-line interface
###############################################################################


def parse_args():
    """Parse command-line arguments"""
    parser = yapecs.ArgumentParser(
        description='Phonetic posteriorgram plotting')
    parser.add_argument(
        '--audio_paths',
        nargs='+',
        type=Path,
        required=False,
        help='Paths to audio files and/or directories')
    parser.add_argument(
        '--audio_extensions',
        nargs='+',
        default=['wav', 'mp3'],
        help='Extensions for audio files in provided directories'
    )
    parser.add_argument(
        '--ppg_paths',
        nargs='+',
        type=Path,
        required=False,
        help='Paths to PPG files and/or directories')
    parser.add_argument(
        '--textgrid_paths',
        nargs='+',
        type=Path,
        required=False,
        help='Paths to textgrid files and/or directories')
    parser.add_argument(
        '--output_paths',
        type=Path,
        nargs='+',
        default=None,
        help='The one-to-one corresponding output paths')
    parser.add_argument(
        '--video',
        action='store_true',
        help='Create video visualizations instead of images'
    )
    parser.add_argument(
        '--pdf',
        action='store_true',
        help='Save resulting images as pdf files'
    )
    parser.add_argument(
        '--checkpoint',
        default=None,
        help='The checkpoint file')
    parser.add_argument(
        '--font_filename',
        default=None,
        help='The font file to use for text'
    )
    parser.add_argument(
        '--gpu',
        type=int,
        help='The index of the GPU to use for inference. Defaults to CPU.')
    return parser.parse_args()


ppgs.plot.from_paths_to_paths(**vars(parse_args()))

==> ppgs-0.0.9.tar.gz: ppgs-0.0.9/ppgs/plot/__main__.py <==
import yapecs
from pathlib import Path

import ppgs


###############################################################################
# PPG inference command-line interface
###############################################################################


def parse_args():
    """Parse command-line arguments"""
    parser = yapecs.ArgumentParser(
        description='Phonetic posteriorgram plotting')
    parser.add_argument(
        '--audio_files',
        nargs='+',
        type=Path,
        help='Audio filenames')
    parser.add_argument(
        '--ppg_files',
        nargs='+',
        type=Path,
        help='PPG filenames')
    parser.add_argument(
        '--second_ppg_files',
        nargs='+',
        type=Path,
        help='Second PPG filenames to compare to')
    parser.add_argument(
        '--textgrid_files',
        nargs='+',
        type=Path,
        help='TextGrid files containing lexical alignments')
    parser.add_argument(
        '--output_files',
        type=Path,
        nargs='+',
        help='The one-to-one corresponding output files')
    parser.add_argument(
        '--checkpoint',
        type=Path,
        help='The checkpoint file')
    parser.add_argument(
        '--font_filename',
        type=Path,
        help='The font file to use for text')
    parser.add_argument(
        '--gpu',
        type=int,
        help='The index of the GPU to use for inference. Defaults to CPU.')
    return parser.parse_args()


ppgs.plot.from_files_to_files(**vars(parse_args()))
